LiveActivitiesChannel class

Channel for Live Activities communication with native platforms

Constructors

LiveActivitiesChannel()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

eventStream Stream
Get the event channel stream for receiving events from native
no setter

Static Methods

invokeMethod<T>({required LiveActivityMethod method, dynamic arguments}) Future<T?>
Invoke a method on the native side