isBodyClick property
bool
get
isBodyClick
Whether the user tapped the notification body rather than a button.
Implementation
bool get isBodyClick => actionIndex < 0;
Whether the user tapped the notification body rather than a button.
bool get isBodyClick => actionIndex < 0;