LiveActivityStatusEvent class

A lifecycle event emitted for a subscribed live notification.

Constructors

LiveActivityStatusEvent({required LiveActivityStatus status, required String liveNotificationId, String? activityId, String? error})
const
LiveActivityStatusEvent.fromMap(Map map)
factory

Properties

activityId String?
Platform-local activity identifier, when the platform provides one.
final
error String?
Error description when status is LiveActivityStatus.error.
final
hashCode int
The hash code for this object.
no setterinherited
liveNotificationId String
Backend id of the live notification this event belongs to.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status LiveActivityStatus
What happened.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited