pushpushgo_sdk library
Classes
- A NavigatorObserver that automatically notifies PPGInAppMessages about route changes.
- LiveActivityClick
- A tap on a Live Activity — either on its body or on one of its action buttons.
- LiveActivityInfo
- Snapshot of a Live Activity currently tracked by the native SDK.
- LiveActivityStatusEvent
- A lifecycle event emitted for a subscribed live notification.
- PPGInAppMessages
- PushPushGo In-App Messages SDK for Flutter
- PPGLiveActivities
- PushPushGo Live Activities for Flutter
- PushpushgoSdk
Enums
- LiveActivityStatus
- Lifecycle status of a Live Activity subscription.
- ResponseStatus
Typedefs
- CustomCodeActionHandler = void Function(String customCode)
- Handler for custom code actions from in-app message buttons
- LiveActivityClickHandler = void Function(LiveActivityClick click)
- Handler for taps on a Live Activity (body or action button)
-
MessageHandler
= dynamic Function(Map<
String, dynamic> message) -
NotificationClickHandler
= dynamic Function(Map<
String, dynamic> message) -
PpgOptions
= Map<
String, String> - SubscriptionHandler = dynamic Function(String serializedJSON)