statusStream property
Stream<LiveActivityStatusEvent>
get
statusStream
Lifecycle events for subscribed live notifications
The stream is a broadcast stream, so it can be listened to from several places. Events that arrived before the first listener attached are replayed to it. Events keep arriving until dispose is called.
Implementation
Stream<LiveActivityStatusEvent> get statusStream {
_statusController ??= StreamController<LiveActivityStatusEvent>.broadcast(
onListen: _flushPendingStatusEvents,
);
_setupEventListening();
return _statusController!.stream;
}